==> qtbase-opensource-src_5.3.2+dfsg.orig.tar.xz: qtbase-opensource-src-5.3.2/src/platformsupport/eglconvenience/qeglplatformwindow_p.h <==
/****************************************************************************
**
** Copyright (C) 2013 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QEGLPLATFORMWINDOW_H
#define QEGLPLATFORMWINDOW_H

#include <qpa/qplatformwindow.h>
#include <EGL/egl.h>

QT_BEGIN_NAMESPACE

class QEGLPlatformBackingStore;
class QPlatformTextureList;

class QEGLPlatformWindow : public QPlatformWindow
{
public:
    QEGLPlatformWindow(QWindow *w);

    virtual void create();

    QEGLPlatformBackingStore *backingStore() { return m_backingStore; }
    void setBackingStore(QEGLPlatformBackingStore *backingStore) { m_backingStore = backingStore; }
    const QPlatformTextureList *textures() const;
    void composited();
    bool isRaster() const;

    WId winId() const Q_DECL_OVERRIDE;

    virtual EGLNativeWindowType eglWindow() const = 0;

private:
    QEGLPlatformBackingStore *m_backingStore;
    bool m_raster;
    WId m_winId;
};

QT_END_NAMESPACE

#endif // QEGLPLATFORMWINDOW_H

==> qtbase-opensource-src-5.4.2.tar.xz: qtbase-opensource-src-5.4.2/src/platformsupport/eglconvenience/qeglplatformwindow_p.h <==
/****************************************************************************
**
** Copyright (C) 2014 Digia Plc and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL21$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia. For licensing terms and
** conditions see http://qt.digia.com/licensing. For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file. Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights. These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QEGLPLATFORMWINDOW_H
#define QEGLPLATFORMWINDOW_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists purely as an
// implementation detail.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <qpa/qplatformwindow.h>
#include <EGL/egl.h>

QT_BEGIN_NAMESPACE

class QEGLPlatformBackingStore;
class QPlatformTextureList;

class QEGLPlatformWindow : public QPlatformWindow
{
public:
    QEGLPlatformWindow(QWindow *w);

    virtual void create();

    QEGLPlatformBackingStore *backingStore() { return m_backingStore; }
    void setBackingStore(QEGLPlatformBackingStore *backingStore) { m_backingStore = backingStore; }
    const QPlatformTextureList *textures() const;
    void composited();
    bool isRaster() const;

    WId winId() const Q_DECL_OVERRIDE;
    void setOpacity(qreal opacity) Q_DECL_OVERRIDE;

    virtual EGLNativeWindowType eglWindow() const = 0;

private:
    QEGLPlatformBackingStore *m_backingStore;
    bool m_raster;
    WId m_winId;
};

QT_END_NAMESPACE

#endif // QEGLPLATFORMWINDOW_H
